NetCalc Change Log
==================

All releases and notable changes will be described here.

NetCalc adheres to `semantic versioning <http://semver.org>`_. In short, this
means the version numbers follow a three-part scheme: *major version*, *minor
version* and *patch number*.

The *major version* is incremented for releases that break compatibility, such
as removing or altering existing functionality. The *minor version* is
incremented for releases that add new visible features, but are still backwards
compatible. The *patch number* is incremented for minor changes such as bug
fixes, that don't change the public interface.


Unreleased__
------------
__ https://github.com/israel-lugo/netcalc/compare/v0.1.0...HEAD


0.1.0_ — 2016-11-01
-------------------

First production release.


.. _0.1.0: https://github.com/israel-lugo/netcalc/tree/v0.1.0
